import { 
  select,
  csv,
  scaleTime,
  scaleLinear,
  extent,
  axisLeft,
	axisBottom} 
from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');


// 	d.mpg = + d.mpg;
//  d.cylinders = + d.cylinders;
//  d.displacement = + d.displacement;
//  d.horsepower = + d.horsepower;
//  d.weight = + d.weight;
//  d.acceleration = + d.acceleration;
//  d.year = + d.year;

const render = data =>{
  const title  = "A week in San Francisco "
  
  const xValue = d => d.timestamp;
  const xAxisLabel = "Time";
  
  const yValue = d => d.temperature;
  const yAxisLabel = "Temperature";
  
  const circleRadius = 6;
  const margin = { top: 50, right: 40, bottom: 88, left: 100 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
  	.domain(extent(data, xValue))			//min to max
  	.range([0, innerWidth])
		.nice();
   
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([innerHeight, 0])
		.nice();	
  	   
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  

  const xAxis = axisBottom(xScale)
		.tickSize(-innerHeight)
  	.tickPadding(15);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10);
  
  const xAxisG = g.append('g')
  	.call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG
    .select('.domain').remove();
  
  xAxisG.append('text')
  	.attr('class','axis-label')
  	.attr('y', 75)
  	.attr('x', innerWidth / 2)
  	.attr('fill','black')
  	.text(xAxisLabel)
    
  
  const yAxisG = g.append('g')
    .call(yAxis)
  yAxisG
		.selectAll('.domain')
			.remove();
  
  yAxisG.append('text')
  	.attr('class','axis-label')
  	.attr('y', -55)
  	.attr('x', -innerHeight / 2)
  	.attr('fill','black')
  	.attr('transform', `rotate(-90)`)
  	.attr('text-anchor', 'middle')
  	.text(yAxisLabel)
  
   
  
	g.selectAll('circle').data(data)
  	.enter().append('circle')
  		.attr('cy', d => yScale(yValue(d)))
  		.attr('cx', d => xScale(xValue(d)))
  		.attr('r', circleRadius);
  
  g.append('text')
  	.attr('class','title')
  	.attr('x', 50)
  	.attr('y', -15)
  	.text(title)
};

csv('https://vizhub.com/curran/datasets/temperature-in-san-francisco.csv')
  .then(data => {
    data.forEach(d => {
      d.temperature = +d.temperature;
      d.timestamp = new Date(d.timestamp);
    });
    render(data);
  });









